strider library

Classes

Stridable<T, E>
Interface for types that can be used in a stride operation.
Stride<T extends Stridable<T, E>, E extends Object>
@EXPERIMENTAL A stride operation that generates an iterable of values from from to to