Stridable<T, E> class abstract

Interface for types that can be used in a stride operation.

Constructors

Stridable()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator +(E other) → T
operator -(E other) → T
operator <(T other) bool
operator <=(T other) bool
operator ==(Object other) bool
The equality operator.
override
operator >(T other) bool
operator >=(T other) bool